package com.fs.live.service;


import com.fs.common.core.domain.R;
import com.fs.live.domain.Live;
import com.fs.live.domain.LiveAutoTask;

import java.util.Date;
import java.util.List;

/**
 * 直播间自动化任务配置Service接口
 *
 * @author fs
 * @date 2025-08-29
 */
public interface ILiveAutoTaskService {
    /**
     * 查询直播间自动化任务配置
     *
     * @param id 直播间自动化任务配置主键
     * @return 直播间自动化任务配置
     */
    LiveAutoTask selectLiveAutoTaskById(Long id);

    /**
     * 查询直播间自动化任务配置列表
     *
     * @param liveAutoTask 直播间自动化任务配置
     * @return 直播间自动化任务配置集合
     */
    List<LiveAutoTask> selectLiveAutoTaskList(LiveAutoTask liveAutoTask);

    /**
     * 新增直播间自动化任务配置
     *
     * @param liveAutoTask 直播间自动化任务配置
     * @return 结果
     */
    R insertLiveAutoTask(LiveAutoTask liveAutoTask);

    /**
     * 复制新增直播间自动化任务配置
     *
     * @param liveAutoTask 直播间自动化任务配置
     * @return 结果
     */
    R copyInsertLiveAutoTask(LiveAutoTask liveAutoTask, Live live);

    /**
     * 修改直播间自动化任务配置
     *
     * @param liveAutoTask 直播间自动化任务配置
     * @return 结果
     */
    R updateLiveAutoTask(LiveAutoTask liveAutoTask);

    /**
     * 批量删除直播间自动化任务配置
     *
     * @param ids 需要删除的直播间自动化任务配置主键集合
     * @return 结果
     */
    int deleteLiveAutoTaskByIds(Long[] ids);

    /**
     * 删除直播间自动化任务配置信息
     *
     * @param id 直播间自动化任务配置主键
     * @return 结果
     */
    int deleteLiveAutoTaskById(Long id);

    List<LiveAutoTask> selectLiveAutoTaskByLiveId(Long existLiveId);
    List<LiveAutoTask> selectNoActivedByLiveId(Long existLiveId, Date now);

    List<LiveAutoTask> selectLiveAutoTaskByLiveIds(List<Long> liveIdLists);

    void recalcLiveAutoTask(Live live);

    void finishLiveAutoTask(LiveAutoTask task);

    List<LiveAutoTask> selectLiveAutoTaskBarrageList(LiveAutoTask liveAutoTask);

    void directInsertLiveAutoTask(LiveAutoTask liveAutoTask);

    void batchInsertLiveAutoTask(List<LiveAutoTask> addList);

    List<LiveAutoTask> selectLiveAutoTaskConsoleList(LiveAutoTask liveAutoTask);

    List<LiveAutoTask> consoleList(Long liveId);

    void deleteAutoTasksByCouponId(Long couponId, Long liveId);
    void deleteAutoTasksByRedId(Long redId, Long liveId);
    void deleteAutoTasksByLotteryId(Long lotteryId, Long liveId);
    void deleteAutoTasksByGoodsId(Long goodsId, Long liveId);
    void deleteLotteryCache(Long lotteryId, Long liveId);
    void deleteRedCache(Long redId, Long liveId);
}
